@@ -150,6 +150,17 @@ codecov <- function(...,
                           slug = slug,
                           commit = commit %||% Sys.getenv("CI_BUILD_REF"))
   # ---------
+  # GitHub Actions
+  # ---------
+  } else if (nzchar(Sys.getenv("GITHUB_ACTION"))) {
+    slug <- Sys.getenv("GITHUB_REPOSITORY")
+    codecov_url <- paste0(base_url, "/upload/v2") # nolint
+    codecov_query <- list(#service = "github",
+                          branch = branch %||% sub("^refs/heads/", "", Sys.getenv("GITHUB_REF")),
+                          build = Sys.getenv("GITHUB_ACTION"),
+                          slug = slug,
+                          commit = commit %||% Sys.getenv("GITHUB_SHA"))
+  # ---------
   # Local GIT
   # ---------
   } else {
